==> qutim_0.2.60-maemo-3.tar.gz: qutim-0.2.60-maemo/translations/bg_BG/kdeintegration.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/kdeintegration.cpp" line="+60"/>
        <source>Ruslan Nigmatullin</source>
        <translation>Руслан Нигматуллин</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Sidorov Aleksey</source>
        <translation>Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>KDENotificationLayer</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/notification/kdenotificationlayer.cpp" line="+121"/>
        <source>Open chat</source>
        <translation>Отваряне на разговор</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
</context>
<context>
    <name>KdeSpellerSettings</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/speller/kdespellersettings.ui" line="+14"/>
        <source>Form</source>
        <translation>Проверка на правописа</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Select dictionary:</source>
        <translation>Избор на речник:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Autodetect of language</source>
        <translation>Автоматично разпознаване на езика</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/kdeintegration.cpp" line="+3"/>
        <source>KDE integration</source>
        <translation>Интеграция с KDE</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Integration with K Desktop Environment</source>
        <translation>Интеграция с K Desktop Environment</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Emoticons</source>
        <translation>KDE емотикони</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Using KDE emoticons packs</source>
        <translation>Използване на пакети с емотикони от KDE</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Crash handler</source>
        <translation>Справяне на KDE с провали</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Handles qutIM&apos;s craches by KCrash</source>
        <translation>Докладване провалите на qutIM посредством KCrash</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Spell checker</source>
        <translation>Проверка на правописа в KDE</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>KDE Icon engine</source>
        <translation>KDE икони</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uses KDE Icon engine for providing icons</source>
        <translation>Използване на пакети с икони от KDE</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Notifications</source>
        <translation>KDE уведомления</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uses KDE notifications</source>
        <translation>Използване на KDE уведомления</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Status Notifier</source>
        <translation>Уведомления за статуса в KDE</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Using new KDE DBus tray specification</source>
        <translation>Използване на новите KDE DBus спецификации за системния поднос</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/speller/kdespellerlayer.cpp" line="+29"/>
        <source>Spell checker</source>
        <translation>Проверка на правописа</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/notification/kdenotificationlayer.cpp" line="-83"/>
        <source>Popups</source>
        <translation>Изскачащи прозорци</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/kdeintegration.cpp" line="-24"/>
        <location line="+3"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
</context>
<context>
    <name>plugmanSettings</name>
    <message>
        <location filename="../../qutim-meta/integrations/kde/src/notification/settings.ui" line="+13"/>
        <source>Form</source>
        <translation>Добавки</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Installed plugins:</source>
        <translation>Инсталирани добавки:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Install from internet</source>
        <translation>Инсталиране от Интернет</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Install from file</source>
        <translation>Инсталиране от файл</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>About</source>
        <translation>За добавката</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Bitstream Vera Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/icons/plugin-logo.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Simple qutIM plugin&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Author: &lt;/span&gt;Sidorov Aleksey&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Contacts: &lt;/span&gt;&lt;a href=&quot;mailto::sauron@citadelspb.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;sauron@citadeslpb.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Bitstream Vera Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/icons/plugin-logo.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Simple qutIM plugin&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Автор: &lt;/span&gt;Алексей Сидоров&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Контакти &lt;/span&gt;&lt;a href=&quot;mailto::sauron@citadelspb.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;sauron@citadeslpb.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
</TS>

==> qutim_0.2.80-maemo-3.tar.gz: qutim-0.2.80-maemo/translations/bg_BG/kdeintegration.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/kdeintegration.cpp" line="+72"/>
        <source>Ruslan Nigmatullin</source>
        <translation>Руслан Нигматуллин</translation>
    </message>
    <message>
        <source>Aleksey Sidorov</source>
        <translation type="obsolete">Алексей Сидоров</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Sidorov Aleksey</source>
        <translation>Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/aboutapp/kdeaboutappdialog.cpp" line="+36"/>
        <source>About qutIM</source>
        <translation>За qutIM</translation>
    </message>
</context>
<context>
    <name>KDENotificationLayer</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/notification/kdenotificationlayer.cpp" line="+121"/>
        <source>Open chat</source>
        <translation>Отваряне на разговор</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
</context>
<context>
    <name>KdeSpellerSettings</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/speller/kdespellersettings.ui" line="+14"/>
        <source>Form</source>
        <translation>Проверка на правописа</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Select dictionary:</source>
        <translation>Избор на речник:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Autodetect of language</source>
        <translation>Автоматично разпознаване на езика</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/kdeintegration.cpp" line="+4"/>
        <source>KDE integration</source>
        <translation>Интеграция с KDE</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Integration with K Desktop Environment</source>
        <translation>Интеграция с K Desktop Environment</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Emoticons</source>
        <translation>KDE емотикони</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Using KDE emoticons packs</source>
        <translation>Използване на пакети с емотикони от KDE</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Crash handler</source>
        <translation>Справяне на KDE с провали</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Handles qutIM&apos;s craches by KCrash</source>
        <translation>Докладване провалите на qutIM посредством KCrash</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE Spell checker</source>
        <translation>Проверка на правописа в KDE</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>KDE Icon engine</source>
        <translation>KDE икони</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uses KDE Icon engine for providing icons</source>
        <translation>Използване на пакети с икони от KDE</translation>
    </message>
    <message>
        <source>KDE Notifications</source>
        <translation type="obsolete">KDE уведомления</translation>
    </message>
    <message>
        <source>Uses KDE notifications</source>
        <translation type="obsolete">Използване на KDE уведомления</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>KDE Status Notifier</source>
        <translation>Уведомления за статуса в KDE</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Using new KDE DBus tray specification</source>
        <translation>Използване на новите KDE DBus спецификации за системния поднос</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>About KDE dialog</source>
        <translation>За KDE</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show &quot;About KDE&quot; menu option</source>
        <translation>Показва менюто &quot;За KDE&quot;</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>KDE About application dialog</source>
        <translation>KDE За програмата</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use kde-specific application about dialog</source>
        <translation>Използва специфичен за KDE диалог &quot;За програмата&quot;</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/speller/kdespellerlayer.cpp" line="+29"/>
        <source>Spell checker</source>
        <translation>Проверка на правописа</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/notification/kdenotificationlayer.cpp" line="-83"/>
        <source>Popups</source>
        <translation>Изскачащи прозорци</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/kdeintegration.cpp" line="-32"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
</context>
<context>
    <name>plugmanSettings</name>
    <message>
        <location filename="../../qutim-meta/plugins/kde-integration/src/notification/settings.ui" line="+13"/>
        <source>Form</source>
        <translation>Добавки</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Installed plugins:</source>
        <translation>Инсталирани добавки:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Install from internet</source>
        <translation>Инсталиране от Интернет</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Install from file</source>
        <translation>Инсталиране от файл</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>About</source>
        <translation>За добавката</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Bitstream Vera Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/icons/plugin-logo.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Simple qutIM plugin&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Author: &lt;/span&gt;Sidorov Aleksey&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Contacts: &lt;/span&gt;&lt;a href=&quot;mailto::sauron@citadelspb.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;sauron@citadeslpb.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Bitstream Vera Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/icons/plugin-logo.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Simple qutIM plugin&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Автор: &lt;/span&gt;Сидоров Алексей&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Контакти &lt;/span&gt;&lt;a href=&quot;mailto::sauron@citadelspb.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;sauron@citadeslpb.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
</TS>
